package com.example.as_trak;

import androidx.activity.result.contract.ActivityResultContracts;
import androidx.annotation.Nullable;
import androidx.databinding.DataBindingUtil;
import androidx.databinding.ObservableBoolean;

import android.annotation.SuppressLint;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ListPopupWindow;
import android.widget.Toast;

import com.example.as_trak.adapter.CargoInfoAdapter;
import com.example.as_trak.adapter.FlightInfoAdapter;
import com.example.as_trak.base.BaseActivity;
import com.example.as_trak.databinding.ActivityLoadMainBinding;
import com.example.as_trak.dialog.AddFlightDialog;
import com.example.as_trak.entity.CargoInfo;
import com.example.as_trak.entity.FlightInfo;
import com.example.as_trak.entity.LoadOperation;
import com.example.as_trak.toast.LoadToast;

import org.litepal.LitePal;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

public class LoadMainActivity extends BaseActivity implements AddFlightDialog.AddFlightDialogCall, CargoInfoAdapter.CargoInfoCall, AdapterView.OnItemClickListener {
    private ObservableBoolean visibState;
    private AddFlightDialog addFlightDialog;
    private List<FlightInfo> flightList;
    private ListPopupWindow lpw;
    private FlightInfo flightInfoTag;
    private CargoInfoAdapter cargoInfoAdapter;
    private List<CargoInfo> cargoInfoList;
    private FlightInfoAdapter adapter;

    private ActivityLoadMainBinding binding;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        binding = DataBindingUtil.setContentView(this, R.layout.activity_load_main);
        visibState = new ObservableBoolean();
        visibState.set(true);
        binding.setVisibState(visibState);
        // 装载器适配
        cargoInfoAdapter = new CargoInfoAdapter(this, this);
        binding.setAdapter(cargoInfoAdapter);
        // 航班添加框
        addFlightDialog = new AddFlightDialog(this);
        addFlightDialog.setCall(this);
        // 航班选择框
        lpw = new ListPopupWindow(this);
        lpw.setAnchorView(binding.loadMainFlightCode);
        // 航班查询
        flightList = LitePal.order("createTime desc").find(FlightInfo.class);
        if (flightList == null) flightList = new ArrayList<>();
        adapter = new FlightInfoAdapter(this, flightList);
        lpw.setAdapter(adapter);
        lpw.setOnItemClickListener(this);
        binding.loadMainFlightCode.setOnClickListener(v -> {
            lpw.show();
        });
        intent = new Intent(this, LoadScanActivity.class);


    }


    // 显示航班添加框
    public void loadAddFlight(View view) {
        addFlightDialog.show();
    }

    // 显示添加货箱按钮
    public void loadAddEdit(View view) {
        visibState.set(false);
    }

    // 添加货箱
    public void loadAddCargo(View view) {
        if (flightInfoTag == null) {
            return;
        }
        String cargoCode = binding.loadMainCargoCode.getText().toString();
        if (cargoCode.isEmpty()) {
            return;
        }
        int id = flightInfoTag.getId();
        int countTag = LitePal.where("cargoCode= ? and flightId=?", cargoCode, String.valueOf(id)).count(CargoInfo.class);
        if (countTag > 0) {
            Toast.makeText(this, "装载单元已经绑定", Toast.LENGTH_SHORT).show();
            return;
        }
        CargoInfo cargoInfo = new CargoInfo();
        cargoInfo.setCount(0);
        cargoInfo.setCargoCode(cargoCode);
        cargoInfo.setFlightId(id);
        cargoInfo.setState("待装载");
        cargoInfo.save();
        cargoInfoList.add(cargoInfo);
        cargoInfoAdapter.notifyDataSetChanged();
        binding.loadMainCargoCode.setText(null);
        Toast.makeText(this, "绑定成功", Toast.LENGTH_SHORT).show();
    }

    // 关闭货箱添加
    public void loadCloseEdit(View view) {
        visibState.set(true);
        binding.loadMainCargoCode.setText(null);
    }

    /**
     * 返回新增的航班信息
     *
     * @param flightCode  航班编号
     * @param destination 三字代码
     * @param date        日期
     * @param time        时间
     */
    @Override
    public void flightInfo(String flightCode, String destination, String date, String time) {
        FlightInfo flightInfo = new FlightInfo();
        flightInfo.setFlightCode(flightCode);
        flightInfo.setDestination(destination);
        flightInfo.setTakeoffDate(date);
        flightInfo.setTakeoffTime(time);
        flightInfo.setCreateTime(new Date());
        flightInfo.save();
        addFlightDialog.dismiss();
        flightList.add(flightInfo);
        adapter.notifyDataSetChanged();
    }

/*
    @Override
    public void sanCodeResult(String code) {
        super.sanCodeResult(code);
        Log.e("TAG", "sanCodeResult:" + code);
    }*/

    @Override
    public void updateCargoInfo(int index) {
        // CargoInfo cargoInfo = cargoInfoList.get(index);
        // cargoInfoAdapter.notifyDataSetChanged();
    }

    @Override
    public void deleteCargoInfo(int index) {
        CargoInfo cargoInfo = cargoInfoList.get(index);
        if (!cargoInfo.getState().equals("待装载")) {
            Toast.makeText(this, "已经装载行李，不能删除", Toast.LENGTH_SHORT).show();
            return;
        }
        cargoInfo.delete();
        cargoInfoList.remove(index);
        cargoInfoAdapter.notifyDataSetChanged();
    }

    private Intent intent;

    public void clickCargoInfo(View view) {
        if (flightInfoTag == null) {
            Toast.makeText(this, "没有选择航班", Toast.LENGTH_SHORT).show();
            return;
        }
        if (cargoInfoList == null || cargoInfoList.isEmpty()) {
            Toast.makeText(this, "没有添加装载单元", Toast.LENGTH_SHORT).show();
            return;
        }
        intent.putExtra("id", flightInfoTag.getId());
        startActivityForResult(intent, 0);
    }

    // 选中航班
    @Override
    public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
        flightInfoTag = flightList.get(position);
        // 添加输入框
        binding.loadMainFlightCode.setText(flightInfoTag.getFlightCode());
        // 查询货框
        selectCargo();
        Toast.makeText(this, "查询成功", Toast.LENGTH_SHORT).show();
        lpw.dismiss();
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        Log.e("TAG", "onActivityResult:重加载");
        selectCargo();
    }

    @SuppressLint("NotifyDataSetChanged")
    private void selectCargo() {
        cargoInfoList = LitePal.where("flightId = ? ",
                String.valueOf(flightInfoTag.getId())).find(CargoInfo.class);
        if (!cargoInfoList.isEmpty()) {
            cargoInfoList.forEach(cargoInfo -> {
                int countNum = LitePal.where("cargoId = ? and type ='正常' and (state IS NULL or state = '修改')",String.valueOf(cargoInfo.getId())).count(LoadOperation.class);
                cargoInfo.setCount(countNum);
            });
        }


        cargoInfoAdapter.setList(cargoInfoList);
        cargoInfoAdapter.notifyDataSetChanged();
    }
}